==> lmms_0.2.1.orig.tar.gz: lmms-0.2.1/include/fade_button.h <==
/*
 * fade_button.h - declaration of class fadeButton 
 *
 * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
 * 
 * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */


#ifndef _FADE_BUTTON_H
#define _FADE_BUTTON_H 

#include "qt3support.h"

#ifdef QT4

#include <QtGui/QAbstractButton>
#include <QtGui/QColor>

#else

#include <qbutton.h>
#include <qcolor.h>

#endif



class fadeButton : public QAbstractButton
{
	Q_OBJECT
public:
	fadeButton( const QColor & _normal_color, const QColor &
					_activated_color, QWidget * _parent );

	virtual ~fadeButton();


public slots:
	void activate( void );
	void reset( void );


protected:
	virtual void paintEvent( QPaintEvent * _pe );


private slots:
	void nextState( void );


private:
	float m_state;
	QColor m_normalColor;
	QColor m_activatedColor;

} ;


#endif

==> lmms_0.3.2.orig.tar.gz: lmms-0.3.2/include/fade_button.h <==
/*
 * fade_button.h - declaration of class fadeButton 
 *
 * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
 * 
 * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 *
 */


#ifndef _FADE_BUTTON_H
#define _FADE_BUTTON_H 

#include "qt3support.h"

#ifdef QT4

#include <QtGui/QAbstractButton>
#include <QtGui/QColor>

#else

#include <qbutton.h>
#include <qcolor.h>

#endif



class fadeButton : public QAbstractButton
{
	Q_OBJECT
public:
	fadeButton( const QColor & _normal_color, const QColor &
					_activated_color, QWidget * _parent );

	virtual ~fadeButton();


public slots:
	void activate( void );
	void reset( void );


protected:
#ifndef QT3
	virtual void customEvent( QEvent * );
#else
	virtual void customEvent( QCustomEvent * );
#endif
	virtual void paintEvent( QPaintEvent * _pe );


private:
	float m_state;
	QColor m_normalColor;
	QColor m_activatedColor;

	void signalUpdate( void );

} ;


#endif
